@@ -1,5 +1,5 @@
 import numpy as np
-import BivTrunc
+import BTcode
 
 def BivTruncSimple(xydat, datlim, lambdax, lambday, mask, deg=1, maxiters1 = 1000,
                   maxiters2 = 100, verbose=False, datwght=1, calccovs=False):
@@ -17,7 +17,7 @@ def BivTruncSimple(xydat, datlim, lambdax, lambday, mask, deg=1, maxiters1 = 100
 	grdsize = len(mask)
     
 	bivest,grdcov,grdest,lvout,fits,info,lscv,likecv,likelihood,fpr,gpr,theta,setheta = \
-         BivTrunc.bivtrunc(xydat,deg,datlim,lambdax,lambday,mask,maxiters1,
+         BTcode.bivtrunc(xydat,deg,datlim,lambdax,lambday,mask,maxiters1,
          maxiters2,grdsize,verbose,datwght,mask2,calccovs)
     
 	return(bivest,grdcov,grdest,lvout,fits,info,lscv,likecv,likelihood,fpr,gpr,theta,setheta)
